This function makes noisy deuteration curves for power calculation purposes.
add_noise_to_curves(curves, per_run_deviations = NULL, relative = TRUE)list of lists of deuteration curves returned by
get_deuteration_curves_from_spectra.
optional, standard deviations of random noise that
will be added to deuteration curves. Either a single number (then the error
at each time point will be the same) or a vector of the same length as number
of unique time points in the experiment. The error will be sampled from
normal distribution with these standard deviations. Default NULL.
logical, if TRUE (default), each deuteration curve will start
at 0 (relative mass will be returned). Default TRUE.
list of lists of data.tables
This function uses
add_noise_to_single_curve