Creates spectra with technical replicates and noise
add_noise_to_spectra(
spectra,
n_replicates = 4,
n_experiments = 100,
undeuterated_mass,
mass_deviations = 50,
intensity_deviations = NULL
)list created by the get_spectra_list
function
number of technical replicates to create
number of replicates of an experiment for power calculation.
the value of mass of an undeuterated peptide
computed by get_undeuterated_mass.
mass deviation in parts per million. Either a single number (then the error at each time point will be the same) or a vector of the same length as number of unique time points in the experiment. The error will be sampled from normal distribution with standard deviation equal to $$mass_deviations * undeuterated_mass/1e6$$ Default to 50.
optional, standard deviations of random noise
that will be added to intensities. Either a single number (then the error at
each time point will be the same) or a vector of the same length as number of
unique time points in the experiment. The error will be sampled from normal
distribution with these standard deviations.Default NULL.
list of lists of data.tables
This function uses
make_experimental_design and
make_noisy_spectra.