View source: R/exchange_rates.R
| get_F_const | R Documentation |
Constants related to water, base and acid in cal/(K * mol)
get_F_const(temp_kelvin, gas_constant)
temp_kelvin |
temperature reaction in Kelvins |
gas_constant |
gas constant (1/(dT * R) = 1.9858775) |
list of constants Fta for acid, Ftb for base and
Ftw for water.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.