View source: R/simulate_HD_exchange.R
| get_HD_matrices_using_markov | R Documentation |
Calculate matrices of simulated exchange required for obtaining empirical distribution.
get_HD_matrices_using_markov( sequence, transition_probs, steps_between_time_points, n_molecules = 100 )
sequence |
amino acid sequence of a peptide as a character vector |
transition_probs |
list of probabilities of exchange returned by the
|
steps_between_time_points |
A vector containing sum of steps between times at which deuteration levels are measured. |
n_molecules |
number of peptide molecules |
The improvement is based on the observation that the considered
process is a Markov chain with transition probabilities P(H -> D) and
P(D -> H), and states H and D.
Matrices are stored in a list of matrices (HD_matrices) -
each matrix for the respective time point of the measurement times.
Using the distributions of process in given times of mesurements, states
H or D are sampled for m peptide molecules
(n_molecules) for each of i = 1,..., n amino acids and stored
in a m x n dimensional matrix for each of the time points of the
measurement given by times.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.