A supplementary function for
get_spectra_list.
get_paired_spectra(theoretical_spectra, reference = NA)a data table or a list of data tables of
theoretical spectra created by the function
simulate_theoretical_spectra.
protection factor that will be used for comparison to other
protection factors in. The function accepts either NA (for comparing
all protection factors), a number (for comparing with reference value of
protection factor) or "all" (for pairwise comparisons of all the possible
combinations). Default NA.
list of data.tables
For more details see get_spectra_list.