calculates supplementary constants for aspartic acid (Asp), glutamic acid (Glu) and histidine (His). Values for mentioned amino acids are pH and temperature dependent, in contrary to the rest amino acids with fixed values.
get_pkc(temp_kelvin, gas_constant, exchange = "HD")temperature reaction in Kelvins
gas constant (1/(dT * R) = 1.9858775)
type of exchange - "HD" for hydrogen to deuterium, "DH" for deuterium to hydrogen (back-exchange). Default "HD".
The function returns a list of asp, glu and his
(pKc values corresponding to amino acids).
Depending on provided exchange direction tabular values of
exponents E_const are assigned. For Asp, Glu and His
the pKc constants are calculated based on the energies of activation
for given amino acid and the chosen exchange direction.