View source: R/noisy_spectra.R
| get_spectra_list | R Documentation |
Create a list of data tables of spectra for all states jointly or paired states.
get_spectra_list(theoretical_spectra, compare_pairs = FALSE, reference = NA)
theoretical_spectra |
a data table or a list of data tables of
theoretical spectra created by the function
|
compare_pairs |
if FALSE, all groups (defined by the protection factor) will be considered jointly. If TRUE (default), each protection factor will be considered together with the protection factor given by the 'reference' parameter. |
reference |
protection factor that will be used for comparison to other
protection factors in. The function accepts either |
If the parameter compare_pairs is FALSE then all the
provided protection factors will be considered jointly. If
compare_pairs is TRUE, then the parameter reference is
necessary (a single number or "all"). Then the data is split via the
supplementary function get_paired_spectra into data
tables of spectra with paired biological states (the reference protection
factor and the protection factor of interest if provided, or all the possible
pairs if reference equals "all").
list of data.tables containing spectra - for paired states or all states.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.