| test_semiparametric | R Documentation |
This function performs the semiparametric test for differences
in deuteration levels. Its input and output are compatible with
the function calculate_hdx_power.
test_semiparametric(data, significance_level = 0.05)
data |
data.table with deuteration curves |
significance_level |
significance level for tests |
This function uses truncated_lines.
The knots considered in the testing procedure are chosen using ridge
regression.
This function returns a data table compatible with the function
calculate_hdx_power.
Other tests:
- test_houde
- test_hdx_analyzer
-test_memhdx_model
Or calculate_hdx_power for estimation of power
of tests for differences in deuteration levels.
theo_spectra_pf_100 <- simulate_theoretical_spectra(sequence = "LVRKDLQN",
charge = c(3, 5),
protection_factor = 100,
times = c(0.167, 5, 10, 30),
pH = 7.5,
temperature = 15,
n_molecules = 500,
time_step_const = 1,
use_markov = TRUE)
theo_spectra_pf_200 <- simulate_theoretical_spectra(sequence = "LVRKDLQN",
charge = c(3, 5),
protection_factor = 200,
times = c(0.167, 5, 10, 30),
pH = 7.5,
temperature = 15,
n_molecules = 500,
time_step_const = 1,
use_markov = TRUE)
theo_spectra_two_states <- rbind(theo_spectra_pf_100, theo_spectra_pf_200)
deut_curves_p_states <- get_noisy_deuteration_curves(theo_spectra_two_states,
n_replicates = 4,
n_experiments = 1,
reference = 100)[[1]][[1]]
test_semiparametric(deut_curves_p_states)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.